#
# spec file for package deepin-image-viewer
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2022 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

Name:           deepin-image-viewer
Version:        5.9.9
Release:        2.4
Summary:        Deepin Image Viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://github.com/linuxdeepin/deepin-image-viewer
Source0:        https://github.com/linuxdeepin/deepin-image-viewer/archive/%{version}/%{name}-%{version}.tar.gz
Source99:       %{name}.appdata.xml
Patch0:         update-libraw-api.patch
BuildRequires:  deepin-gettext-tools
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  dtkcore >= 5.0.0
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libimageviewer-devel
BuildRequires:  libqt5-linguist
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(gio-qt)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(udisks2-qt5)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Deepin Image Viewer is the Image Viewer for Deepin Desktop Environment(DDE)

%lang_package

%prep
%autosetup -p1
sed -i "s/(lrelease/(lrelease-qt5/g" src/src.pro
# sed -i '/FIF_FAXG3/d' src/src/utils/unionimage.cpp
sed -i 's/Exec=deepin-image-viewer/Exec=env QT_QPA_PLATFORMTHEME=deepin deepin-image-viewer/g' \
src/%{name}.desktop
sed -i 's|"../libimageviewer/image-viewer_global.h"|<libimageviewer/image-viewer_global.h>|g' \
src/src/module/view/homepagewidget.cpp

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DAPP_VERSION=%{version}-%{distribution} \
       -DVERSION=%{version}-%{distribution}
%cmake_build

%install
%cmake_install
# Install appdata
install -d %{buildroot}%{_datadir}/appdata
cp %{SOURCE99} %{buildroot}%{_datadir}/appdata/
# Fix version in appdata
RELEASE_DATE=$(stat --format="%%y" %{SOURCE0} | grep -Po "\\d{4}-\\d{2}-\\d{2}")
sed -i "s/@VERSION@/%{version}/g;s/@DATE@/$RELEASE_DATE/g" \
%{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

# Fix desktop profile
%suse_update_desktop_file -r -G "Deepin Image Viewer" %{name} Graphics 2DGraphics RasterGraphics Viewer

# Find translations
%find_lang %{name} --with-qt
%fdupes %{buildroot}

%files
%doc README.md README.zh_CN.md
%license LICENSE.txt
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/icons/
%{_datadir}/deepin-manual/manual-assets/application/%{name}
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_libdir}/qt5/plugins/imageformats/libxraw.so*
%{_datadir}/dbus-1/services/com.deepin.ImageViewer.service

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/translations
%lang(ast) %{_datadir}/deepin-image-viewer/translations/deepin-image-viewer_ast.qm
%{_datadir}/%{name}/translations/deepin-image-viewer.qm

%changelog
* Fri Mar 29 2024 Max Lin <mlin@suse.com>
- Refactor update-libraw-api.patch make it works between openSUSE
  products
* Sat Jan 28 2023 Hillwood Yang <hillwood@opensuse.org>
- Add update-libraw-api.patch, update api for libraw
* Sat Jan 21 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.9
  * Fix bugs
* Sat Nov 26 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.7
  * Fix bugs
- Drop fix-library-link.patch
* Fri Aug 26 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.4
  * Add event tracking feature
* Thu Jun 30 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.2
  * Fix bugs
- Add fix-library-link.patch
* Tue Apr 12 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.13
  * Bring edit feature
  * Fix bugs
* Sun Jan 30 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.2
  * Add ocr feature
  * fix bugs
* Mon Jul 26 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.11
  * Update translations
  * Fix bugs
* Wed Jun  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix broken release date in appdata
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.7.8
  * Bugfix release
- Use find_lang macro
* Sun May 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Stop owning directories provided by filesystem and other packages
  (every dir should only have one owner) (bsc#1184786)
* Sat Apr 17 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.4
  * Fix bugs
  * Update help documents
* Sat Apr 17 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.4
  * Fix bugs
  * Update help document
* Fri Feb 19 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.3.73
  * Use new dtk api
  * The new ui design
- Drop deepin-image-viewer-Qt-5_15.patch, fixed by other way in spec
- Drop Add-missing-return-function.patch, merged by upstream
* Thu Jun 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-image-viewer-Qt-5_15.patch
  * Support Qt 5.15
- Rename deepin-image-viewer-appdata.xml to deepin-image-viewer.appdata.xml
* Thu Aug  1 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix build with new gcc, add Add-missing-return-function.patch
* Thu Jul 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.3.18
  * use QPrintPropertiesDialog replace QPageSetupDialog
  * Remember last choosed path
  * Remove unused code
  * Fix can not copy images to windows applications
  * Not using color printing even if printers supports it
  * QSqlDatabase and QSqlQuery thread-safety problem, used QMutexLocker;
    DBManager
  * improve english
  * Translation update.
  * Forward the navigation wheel event of the NavigationWidget to the ImageView
  * Fix freeimage plugin caused crash
* Thu Mar  7 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.3.8
  * Fix a crash in ImageWidget::event
  * Support open svg
  * Add swipe to go preview/next support
  * Add pinch to zoom gesture
  * Zoom under the cursor
  * Fix use build version.
  * Fix navigation bar close button.
  * Fix fullscreen right menu cursor.
  * Fix image view cursor.
  * Fix fit the image to window.
  * Fix the "Ctrl+C" shortcut is invalid
  * Fix decide image format form the image file content
  * Fix open the current path when the command lines is empty
  * Support print preview
  * Update ts file and deepin vendor support
  * Use the file name sort the image list
  * Support the recent file spec
  * Fix empty command can start a new window
  * Fix shortcut preview info is empty
  * Fix shortcut is invalid
* Wed Mar 21 2018 hillwood@opensuse.org
- Update version to 1.2.17
  * Add notice for tif
  * Add manual id
  * Imageutils cutSquareImage support hidpi
  * Fix bugs
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 1.2.16.4
  * update some translations.
  * Fix some bugs.
* Tue Oct  3 2017 hillwood@opensuse.org
- Initial package.
